summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneywizard_p.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-05 06:00:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-05 06:00:29 +0000
commitfecb0e67b23e8b83ba7fc881bb57bc48c0852d62 (patch)
tree6b8614802f0d01b353bc9ba78aff2090846c198e /kmymoney2/widgets/kmymoneywizard_p.h
parentdadc34655c3ab961b0b0b94a10eaaba710f0b5e8 (diff)
downloadkmymoney-fecb0e67b23e8b83ba7fc881bb57bc48c0852d62.tar.gz
kmymoney-fecb0e67b23e8b83ba7fc881bb57bc48c0852d62.zip
TQt4 port kmymoney
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1239855 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/widgets/kmymoneywizard_p.h')
-rw-r--r--kmymoney2/widgets/kmymoneywizard_p.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kmymoney2/widgets/kmymoneywizard_p.h b/kmymoney2/widgets/kmymoneywizard_p.h
index 92d1152..853cb46 100644
--- a/kmymoney2/widgets/kmymoneywizard_p.h
+++ b/kmymoney2/widgets/kmymoneywizard_p.h
@@ -20,7 +20,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qobject.h>
+#include <tqobject.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -32,18 +32,19 @@
* @author Thomas Baumgart (C) 2006
*
* This class represents a helper object required
- * to be able to use Qt's signal/slot mechanism within
+ * to be able to use TQt's signal/slot mechanism within
* the KMyMoneyWizardPage object which cannot be
* derived from QObject directly.
*/
-class KMyMoneyWizardPagePrivate : public QObject
+class KMyMoneyWizardPagePrivate : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
*/
- KMyMoneyWizardPagePrivate(QObject* parent, const char* name = 0);
+ KMyMoneyWizardPagePrivate(TQObject* tqparent, const char* name = 0);
void emitCompleteStateChanged(void);
@@ -32,18 +32,19 @@
* the KMyMoneyWizardPage object which cannot be
- * derived from QObject directly.
+ * derived from TQObject directly.
*/